@@ -1,9 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v5.0.2-2-g6d9ba73
+# git description: v5.0.3-1-g88233fc
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Tapper specific TAP handling
-$Tapper::TAP::Harness::VERSION = '5.0.3';
+$Tapper::TAP::Harness::VERSION = '5.0.4';
 use 5.010;
 use strict;
 use warnings;
@@ -560,7 +560,7 @@ sub generate_html
         # unix shell level
         my $prove = _get_prove() or die "Can not find 'prove', searched near $^X";
 
-        my $cmd = qq{cd $temp/section ; $^X $prove -vm --exec 'cat' --formatter=TAP::Formatter::HTML `find -type f | sed -e 's,^\./,,' | sort`};
+        my $cmd = qq{cd $temp/section ; $^X $prove -vm --exec 'cat' --formatter=TAP::Formatter::HTML `find . -type f -print | sed -e 's,^\./,,' | sort`};
         my $html = qx( $cmd );
 
         $html = _fix_generated_html( $html );
